!> A module.
module doxytest
    interface
        !> A subroutine.
        !! @param[out] a Output.
        !! @param dummy A dummy procedure.
        subroutine test(dummy, a)
            interface
                !> A dummy procedure.
                !! @param b Input.
                subroutine dummy(b)
                    real, intent(in) :: b
                end subroutine dummy
            end interface
            real, intent(out) :: a
        end subroutine test
        !> Another subroutine.
        !! @param[in] c Input.
        subroutine test2(c)
            real, intent(in) :: c
        end subroutine test2
    end interface

    contains

    !> A module procedure.
    !! @param[in] d Input.
    subroutine test3(d)
        real, intent(in) :: d
    end subroutine test3
end module doxytest

